@@ -1,9 +1,9 @@
-PLUGIN_FORBIDDEN_NAME = ';;'
-
+from ._forbidden_name import PLUGIN_FORBIDDEN_NAME # flake8: noqa
 from .with_info_file import WithInfoFileFilter
 from .matching_regex import MatchingRegexFileFilter
 from .filenames import FilenameFileFilter
 
+
 __all__ = ["WithInfoFileFilter",
            "MatchingRegexFileFilter",
            "FilenameFileFilter"]
